## v0.4.0 (2025-08-15)

### Feat

- support for subparsers and format customization

## v0.3.1 (2024-11-21)

### Fix

- fix issue with publishing to PyPI

## v0.3.0 (2024-11-21)

### Fix

- correct 'check' argument behavior, add test
- automatically add markdown file directory to sys.path
- set maximum width of the command help to 100 chars

## v0.2.0 (2024-11-21)

### Refactor

- run hook on .py or .md changes
- **setup**: switch to pyproject.toml

## v0.1.0 (2024-11-21)

### Feat

- initial version
